@@ -110,7 +110,7 @@ class Utils:
     @classmethod
     def obfuscate_by_type(cls, data, field_name, obfuscation_type):
         if obfuscation_type == Obfuscation_Type.XML:
-            if field_name in data:
+            if field_name.lower() in data.lower():
                 start_indicator = "(?i)(<\\s*(\\w+\\:)?\\s*{}(\\s*[\\s\\S]*?>)?)".format(re.escape(field_name))
                 end_indicator = "(?i)(<\\/\\s*(\\w+\\:)?\\s*{}>)".format(re.escape(field_name))
 
@@ -123,7 +123,7 @@ class Utils:
                     return cls.obfuscate(data, start_index, end_index)
 
         if obfuscation_type == Obfuscation_Type.JSON:
-            if field_name in data:
+            if field_name.lower() in data.lower():
                 indicator = '(?i)((\\"{}\\"\\s*:\\s*\\")((\\\\"|[^\\\\\"])*)\\")'.format(re.escape(field_name))
                 matches = re.search(indicator, data)
 
@@ -134,7 +134,7 @@ class Utils:
                     return cls.obfuscate(data, start_index, end_index)
 
         if obfuscation_type == Obfuscation_Type.URL:
-            if field_name in data:
+            if field_name.lower() in data.lower():
                 indicator = "(?i)((((\\?|\\&){}=)((\\\"|[^\\&])*)))".format(re.escape(field_name))
                 matches = re.search(indicator, data)
 
